@@ -12,7 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * As an exception, when this program is distributed through (i) the App Store
  * by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or (iii) Google Play
@@ -21,7 +21,7 @@
  * terms of service.
  */
 
-/* 
+/*
  * This header provide some dummy replacements of OpenMP functions. We use it
  * to compile Normaliz without OpenMP.
  */
@@ -37,7 +37,7 @@ inline int omp_in_parallel() {
     return false;
 }
 
-inline int omp_get_level(){
+inline int omp_get_level() {
     return 0;
 }
 
@@ -53,18 +53,21 @@ inline int omp_get_max_threads() {
     return 1;
 }
 
-inline int omp_get_ancestor_thread_num(int level) {
+inline int omp_get_ancestor_thread_num(int) {
     return 0;
 }
 
-inline int omp_set_nested(int on_off) {
+inline int omp_set_nested(int) {
     return 0;
 }
 
-inline int omp_set_num_threads(int max_threads) {
+inline int omp_set_max_active_levels(int) {
     return 0;
 }
 
+inline int omp_set_num_threads(int) {
+    return 0;
+}
 
 #endif /* ifndef _OPENMP */
 #endif /* MY_OMP_H_ */
